Learn R Programming

enrichit (version 0.1.2)

gseaScores: Calculate GSEA Running Enrichment Scores

Description

Calculate GSEA Running Enrichment Scores

Usage

gseaScores(geneList, geneSet, exponent = 1, fortify = FALSE)

Value

If fortify = TRUE, a data frame containing the running enrichment scores and positions. If fortify = FALSE, a numeric value representing the Enrichment Score (ES).

Arguments

geneList

a named numeric vector of gene statistics (e.g., t-statistics or log-fold changes), sorted in decreasing order.

geneSet

a character vector of gene IDs belonging to the gene set.

exponent

a numeric value defining the weight of the running enrichment score. Default is 1.

fortify

logical. If TRUE, returns a data frame with columns x, runningScore, and position. If FALSE (default), returns the enrichment score (ES).

Author

Guangchuang Yu