Calculate GSEA Running Enrichment Scores
gseaScores(geneList, geneSet, exponent = 1, fortify = FALSE)If fortify = TRUE, a data frame containing the running enrichment scores and positions.
If fortify = FALSE, a numeric value representing the Enrichment Score (ES).
a named numeric vector of gene statistics (e.g., t-statistics or log-fold changes), sorted in decreasing order.
a character vector of gene IDs belonging to the gene set.
a numeric value defining the weight of the running enrichment score. Default is 1.
logical. If TRUE, returns a data frame with columns x, runningScore, and position.
If FALSE (default), returns the enrichment score (ES).
Guangchuang Yu